@@ -138,6 +138,7 @@ def upload_file(
     path_or_fileobj: Union[str, Path, bytes, BinaryIO],
     path_in_dataset: str,
     id: str,
+    overwrite: bool = False,
     token: Optional[str] = None,
 ):
     if token is None:
@@ -164,6 +165,7 @@ def upload_file(
     # TODO: reivison and timestamp
     # Specify the bucket name and the object key
     bucket_name = upload_info.bucket
+    prefix = upload_info.prefix_to_save
     object_key = os.path.join(
         upload_info.prefix_to_save, generate_timestamped_string(1), path_in_dataset
     )
@@ -176,12 +178,39 @@ def upload_file(
             # Upload a binary stream
             s3.put_object(Bucket=bucket_name, Key=object_key, Body=path_or_fileobj)
     except Exception as e:
-        print(f"Error getting object '{object_key}' from bucket '{bucket_name}': {e}")
+        print(f"Error putting object '{object_key}' from bucket '{bucket_name}': {e}")
+    new_dataset_files: List[DatasetFile] = []
+    found_the_same_file = False
+    for file in get_dataset(id, token).files:
+        print("hello", _get_file_in_dataset(prefix, file.key))
+        if _get_file_in_dataset(prefix, file.key) != path_in_dataset:
+            new_dataset_files.append(file)
+        elif overwrite:
+            found_the_same_file = True
+            new_dataset_files.append(DatasetFile("", object_key, 0))
+        else:
+            print("file exists, skip uploading")
+            return
+    if not found_the_same_file:
+        new_dataset_files.append(DatasetFile("", object_key, 0))
+    _update_dataset(id, new_dataset_files, token)
 
-    dataset_files = get_dataset(id, token).files
-    dataset_files.append(DatasetFile("", object_key, 0))
-    # pprint.pp(dataset_files)
-    _update_dataset(id, dataset_files, token)
+
+# "dataset/59ad0f2e21100106622a1f0c/1721718054361_1/a/b/c.txt"
+# get a/b/c.txt
+def _get_file_in_dataset(prefix: str, object_key: str) -> str:
+    # Check if the prefix is in the object key
+    if object_key.startswith(prefix):
+        # Find the position where the prefix ends
+        prefix_end_index = len(prefix)
+        # Find the position of the first slash after the prefix
+        next_slash_index = object_key.find("/", prefix_end_index)
+        # Extract the file path from the object key
+        file_path = object_key[next_slash_index + 1 :]
+        return file_path
+    else:
+        # If the prefix is not found, return an empty string or raise an error
+        return ""
 
 
 # 初始化cache目录
